"""FasCraft CLI commands package."""

from . import generate, list, new, remove, update, analyze, migrate, config

__all__ = ["new", "generate", "list", "remove", "update", "analyze", "migrate", "config"]
